@@ -29,6 +29,7 @@ from ctypes import (
     Structure,
     c_longlong,
     c_char_p,
+    cast,
 )
 from enum import IntEnum
 from pathlib import Path
@@ -40,8 +41,8 @@ DLLPATH = str(
     Path(getenv("PROGRAMFILES")) / "National Instruments/Shared/TDMS/tdms.dll"
 )
 TDMSDLL = cdll.LoadLibrary(DLLPATH)
-uInt32_MAX = 2 ** 32 - 1
-uInt64_MAX = 2 ** 64 - 1
+uInt32_MAX = 2**32 - 1
+uInt64_MAX = 2**64 - 1
 TDS_VERSION_2_0 = 4713
 
 
@@ -76,6 +77,11 @@ class tdsTime(Structure):
         dt = datetime(1904, 1, 1, tzinfo=timezone.utc) + timedelta(seconds=seconds)
         return dt.astimezone().replace(tzinfo=None)
 
+    @property
+    def value(self):
+        """as_datetime()"""
+        return self.as_datetime()
+
 
 class tdsDataType(CtypesEnum):
     """TDS data types"""
@@ -554,13 +560,14 @@ def _getstrings(cnt, fileid, objid):
     -------
     data
     """
-    buffer = (POINTER(c_char_p) * cnt)()
-    sizes = (POINTER(c_uint32) * cnt)()
+    buffer = cast((c_char_p * cnt)(), POINTER(c_char_p))
+    sizes = cast((c_uint32 * cnt)(), POINTER(c_uint32))
+    _getstrings.call(
+        byref(buffer), byref(sizes), 0, byref(c_size_t(cnt)), fileid, objid, True
+    )
     strings = []
-    # have to iterate for some unknown reason
     for idx in range(cnt):
-        _getstrings.call(buffer, sizes, idx, byref(c_size_t(cnt)), fileid, objid, True)
-        strings.append(buffer[0].contents.value.decode())
+        strings.append(buffer[idx].decode())
     return strings
 
 
